package ru.crystals.setapi.plugins;

import org.slf4j.Logger;
import ru.crystals.pos.api.events.ShiftEventListener;

/**
 * Простейшая реализация слушателя манипуляций с кассовой сменой.<br>
 * Пишет в лог при возникновении событий открытия и закрытия смены.
 */
public class ShiftEventListenerImpl implements ShiftEventListener {
    private Logger logger;

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link ShiftEventListenerImpl}.
     * @param logger логописалка, которая используется для вывода сообщений в лог. Важно использовать
     *               тот же экземпляр логописалки, что использует плагин, потому что только так
     *               можно гарантировать её корректную инициализацию. Самостоятельная инициализация её
     *               как <code>LoggerFactory.getLogger(&lt;class name&gt;)</code> не является корректной в плагинах Set API.
     */
    public ShiftEventListenerImpl(Logger logger) {
        this.logger = logger;
    }

    @Override
    public void onShiftOpened(int newShiftNumber) {
        logger.info("[{}] Opened shift number {}", this.getClass(), newShiftNumber);
    }

    @Override
    public void onShiftClosed() {
        logger.info("[{}] Current shift has been closed", this.getClass());
    }
}
