package ru.crystals.pos.api.card;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Collection;

import ru.crystals.pos.spi.receipt.BonusBalance;
import ru.crystals.pos.spi.receipt.BonusSubBalance;

/**
 * Бонусный баланс карты.
 */
public class BonusBalanceEntity implements BonusBalance {
    
    private BigDecimal balance;
    
    private BigDecimal sumAllowedToChargeOff;
    
    private BigDecimal sumToChargeOff;

    private String bonusProcessingDisplayName;

    private BigDecimal multiplier;

    private BigDecimal rate;

    private BalanceType balanceType = BalanceType.BONUSES;

    private Collection<BonusSubBalance> subBalances = new ArrayList<>();

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link BonusBalanceEntity}.
     * @param balance текущий баланс бонусов на счету.
     */
    public BonusBalanceEntity(BigDecimal balance) {
        super();
        this.balance = balance;
    }

    @Override
    public BigDecimal getBalance() {
        return balance;
    }
    
    /**
     * Установить текущий баланс бонусов на счету.
     * @param balance баланс бонусов
     */
    public void setBalance(BigDecimal balance) {
        this.balance = balance;
    }

    @Override
    public BigDecimal getSumAllowedToChargeOff() {
        return sumAllowedToChargeOff;
    }
    
    /**
     * Установить количество бонусов, что позволено списать с этого баланса в текущем чеке.
     * @param sumAllowedToChargeOff {@code null}, если расчет этого "потолка списания" не производился (неизвестно сколько можно списать).
     */
    public void setSumAllowedToChargeOff(BigDecimal sumAllowedToChargeOff) {
        this.sumAllowedToChargeOff = sumAllowedToChargeOff;
    }

    @Override
    public BigDecimal getSumToChargeOff() {
        return sumToChargeOff;
    }

    /**
     * Установить количество бонусов, которые можно списать в текущем чеке.
     * @param sumToChargeOff количество бонусов, которые можно списать в текущем чеке.
     */
    public void setSumToChargeOff(BigDecimal sumToChargeOff) {
        this.sumToChargeOff = sumToChargeOff;
    }

    @Override
    public String getBonusProcessingDisplayName() {
        return bonusProcessingDisplayName;
    }

    /**
     * Установить наименование бонусной программы/процессинга для отображения в GUI кассы.
     * @param bonusProcessingDisplayName наименование бонусного процессинга.
     */
    public void setBonusProcessingDisplayName(String bonusProcessingDisplayName) {
        this.bonusProcessingDisplayName = bonusProcessingDisplayName;
    }

    @Override
    public BigDecimal getMultiplier() {
        return multiplier;
    }

    /**
     * Установить коэффициент перевода бонусокопеек в бонусорубли
     * @param multiplier коэффициент перевода бонусокопеек в бонусорубли
     * @since 0.0.55
     */
    public void setMultiplier(BigDecimal multiplier) {
        this.multiplier = multiplier;
    }

    @Override
    public BigDecimal getRate() {
        return rate;
    }

    /**
     * Установить курс для конвертации бонусов в деньги
     * @param rate курс для конвертации бонусов в деньги
     * @since 0.0.55
     */
    public void setRate(BigDecimal rate) {
        this.rate = rate;
    }

    @Override
    public BalanceType getBalanceType() {
        return balanceType;
    }

    /**
     * Установить тип баланса, если например бонусы используются как фишки/марки и т.п.,
     * то списание их происходит нелинейно
     *
     * @param balanceType тип баланса
     * @since 0.0.60
     */
    public void setBalanceType(BalanceType balanceType) {
        this.balanceType = balanceType;
    }

    @Override
    public Collection<BonusSubBalance> getSubBalances() {
        return subBalances;
    }

    @Override
    public String toString() {
        return "BonusBalanceEntity{" +
                "balance=" + balance +
                ", sumAllowedToChargeOff=" + sumAllowedToChargeOff +
                ", sumToChargeOff=" + sumToChargeOff +
                ", bonusProcessingDisplayName=" + bonusProcessingDisplayName +
                ", multiplier=" + multiplier +
                ", rate=" + rate +
                '}';
    }
}
