package ru.crystals.pos.api.events;

import ru.crystals.pos.spi.POSEventListener;

/**
 * Слушатель событий открытия и закрытия смены на кассе.<br>
 * Для того, чтобы слушать кассовые события, необходимо создать класс, реализующий данный интерфейс,
 * затем создать в классе плагина поле с этим типом класса, помеченное аннотацией {@link ru.crystals.pos.spi.annotation.POSEventListener},
 * чтобы касса могла уведомлять его о событиях изменения смены.
 * @since 0.0.38
 */
public interface ShiftEventListener extends POSEventListener {

    /**
     * Вызывается при завершении открытии кассой смены.
     * @param newShiftNumber номер открытой смены
     */
    void onShiftOpened(int newShiftNumber);

    /**
     * Вызывается при завершении закрытия смены.
     */
    void onShiftClosed();
}
