package ru.crystals.pos.api.ext.loyal.dto;

import ru.crystals.pos.api.plugin.goods.NewLineItem;

import java.util.HashMap;
import java.util.Map;

/**
 * Результат обработки плагином события добавления товара в чек произвольного возврата.
 */
public class AddForRefundResult {
    /**
     * Сущность для передачи кассе данных о новой позиции чека.
     */
    private NewLineItem newLineItem;

    /**
     * Дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек.
     */
    private Map<String, String> extendedReceiptAttributes = new HashMap<>();

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AddForRefundResult}.
     */
    public AddForRefundResult() {
        // Nop
    }

    /**
     * Конструктор класса. Создаёт новый экземпляр класса {@link AddForRefundResult}
     *
     * @param newLineItem сущность для передачи кассе данных о новой позиции чека
     */
    public AddForRefundResult(NewLineItem newLineItem) {
        this.newLineItem = newLineItem;
    }

    /**
     * Возвращает сущность для передачи кассе данных о новой позиции чека.
     *
     * @return сущность для передачи кассе данных о новой позиции чека.
     */
    public NewLineItem getNewLineItem() {
        return newLineItem;
    }

    /**
     * Устанавливает сущность для передачи кассе данных о новой позиции чека.
     *
     * @param newLineItem сущность для передачи кассе данных о новой позиции чека
     */
    public void setNewLineItem(NewLineItem newLineItem) {
        this.newLineItem = newLineItem;
    }

    /**
     * Возвращает дополнительные данные в формате &lt;ключ, значение&gt;, которые будут добавлены в чек.
     *
     * @return коллекция ключей и значений
     */
    public Map<String, String> getExtendedReceiptAttributes() {
        return extendedReceiptAttributes;
    }

    @Override
    public String toString() {
        return "AddForSaleResult{" +
                "newLineItem=" + newLineItem +
                ", extendedReceiptAttributes=" + extendedReceiptAttributes +
                '}';
    }
}
