package ru.crystals.pos.api.ext.loyal.dto;

import ru.crystals.pos.spi.receipt.LineItem;

import java.util.HashMap;
import java.util.Map;

/**
 * Результат обработки плагинами лояльности события начала расчета скидок.
 *
 * @since 0.0.70
 */
public class PreDiscountResult {
    /**
     * Мапа расширенных атрибутов чека.
     *
     * @since 0.0.70
     */
    private final Map<String, String> receiptAttributeMap = new HashMap<>();

    /**
     * Мапа расширенных атрибутов позиции. Ключом в мапе служит порядковый номер позиции, который получается как
     * {@link LineItem#getNumber()}, значением в мапе - мапа идентификаторов атрибутов и значений их.
     *
     * @since 0.0.70
     */
    private final Map<Integer, Map<String, String>> positionAttributeMap = new HashMap<>();

    /**
     * Возвращает мапу расширенных атрибутов чека. Ключом в мапе служит произвольный строковый идентификатор атрибута,
     * значением - значение атрибута.
     *
     * @return мапа расширенных атрибутов чека.
     * @since 0.0.70
     */
    public Map<String, String> getReceiptAttributeMap() {
        return receiptAttributeMap;
    }

    /**
     * Возвращает мапу расширенных атрибутов позиций. Ключом в мапе служит номер позиции, получаемый как {@link LineItem#getNumber()},
     * значением - мапа атрибутов, которые присвоены данной позиции.
     *
     * @return мапа расширенных атрибутов позиций.
     * @see #addPositionAttribute(int, String, String)
     * @since 0.0.70
     */
    public Map<Integer, Map<String, String>> getPositionAttributeMap() {
        return positionAttributeMap;
    }

    /**
     * Добавляет к позиции с указанным номером заданный атрибут и его значение.
     *
     * @param number номер позиции значение нужно добавить к которой.
     * @param key    идентификатор атрибута.
     * @param value  значение атрибута.
     * @since 0.0.70
     */
    public void addPositionAttribute(int number, String key, String value) {
        positionAttributeMap.computeIfAbsent(number, k -> new HashMap<>());
        positionAttributeMap.get(number).put(key, value);
    }

    @Override
    public String toString() {
        return "PreDiscountResult{" +
                "receiptAttributeMap=" + receiptAttributeMap +
                ", positionAttributeMap=" + positionAttributeMap +
                '}';
    }
}
