package ru.crystals.pos.api.ext.loyal.dto;

/**
 * Текст с указанием номера шрифта и атрибутов.
 * @since 0.0.41
 */
public class SlipText {
    /**
     * Параметры текста - номер шрифта и атрибуты, для формирования можно использовать {@link SlipTextOptions}
     * либо спецификацию используемого ФР
     */
    private int options = SlipTextOptions.PIRIT_FONT_0;

    /**
     * Альтернативный параметр текста - размер. Может сочетаться со стилем, не сочетается с номером шрифта.
     * @since 0.0.46
     */
    private TextSize size;

    /**
     * Альтернативный параметр текста - стиль. Может сочетаться с размером, не сочетается с номером шрифта.
     * @since 0.0.46
     */
    private TextStyle style;

    /**
     * Текст для вывода на ФР, может являться частью абзаца
     */
    private String text;

    /**
     * Конструктор по-умолчанию. Создаёт новый экземпляр класса {@link SlipText}.
     */
    public SlipText() {
        //
    }

    /**
     * Конструктор с параметрами. Создаёт новый экземпляр класса {@link SlipText}.
     * @param text текст для вывода на ФР, может являться частью абзаца
     * @param options параметры текста - номер шрифта и атрибуты, для формирования можно использовать {@link SlipTextOptions}
     *                либо спецификацию используемого ФР
     */
    public SlipText(String text, int options) {
        this(text, options, null, null);
    }

    /**
     * Конструктор с параметрами. Создаёт новый экземпляр класса {@link SlipText}.
     * @param text текст для вывода на ФР, может являться частью абзаца
     * @param size размер шрифта
     * @param style стиль шрифта
     */
    public SlipText(String text, TextSize size, TextStyle style) {
        this(text, 0, size, style);
    }

    /**
     * Конструктор с параметрами. Создаёт новый экземпляр класса {@link SlipText}.
     * @param text текст для вывода на ФР, может являться частью абзаца
     * @param options параметры текста
     * @param size размер шрифта
     * @param style стиль шрифта
     */
    public SlipText(String text, int options, TextSize size, TextStyle style) {
        this.text = text;
        this.options = options;
        this.size = size;
        this.style = style;
    }

    /**
     * @return параметры текста - номер шрифта и атрибуты, для формирования можно использовать {@link SlipTextOptions}
     *      либо спецификацию используемого ФР.
     */
    public int getOptions() {
        return options;
    }

    /**
     * @param options параметры текста - номер шрифта и атрибуты, для формирования можно использовать {@link SlipTextOptions}
     *                либо спецификацию используемого ФР.
     */
    public void setOptions(int options) {
        this.options = options;
    }

    /**
     * @return текст для вывода на ФР, может являться частью абзаца.
     */
    public String getText() {
        return text;
    }

    /**
     * @param text текст для вывода на ФР, может являться частью абзаца.
     */
    public void setText(String text) {
        this.text = text;
    }

    /**
     * @return размер шрифта.
     */
    public TextSize getSize() {
        return size;
    }

    /**
     * @param size размер шрифта.
     */
    public void setSize(TextSize size) {
        this.size = size;
    }

    /**
     * @return стиль шрифта.
     */
    public TextStyle getStyle() {
        return style;
    }

    /**
     * @param style стиль шрифта.
     */
    public void setStyle(TextStyle style) {
        this.style = style;
    }

    @Override
    public String toString() {
        return "SlipText{" +
                "options=" + options +
                ", size=" + size +
                ", style=" + style +
                ", text='" + text + '\'' +
                '}';
    }
}
