package ru.crystals.pos.api.plugin;

import ru.crystals.pos.api.plugin.payment.RefundPreparationResult;
import ru.crystals.pos.spi.plugin.payment.RefundPreparationRequest;

/**
 * Интерфейс, позволяющий плагину участвовать в подготовке кассы к проведению возврата
 * <p>
 * Должен быть реализован в дополнение к {@link PaymentPlugin}
 *
 * @since 1.5.0
 */
public interface RefundPreparationPlugin {

    /**
     * Вызывается при возврате по чеку в процессе формирования списка возвращаемых транзакций.
     * <p>
     * <p>
     * Не вызывается, если в доступных для возврата транзакциях нет транзакций плагина.
     * <p>
     * Не вызывается, если возврат плагином запрещен через общую настройку "возвращать дополнительными способами вместо плагина" или ее аналоги
     * <p>
     * Позволяет, например:
     * <ul>
     * <li>изменить название транзакции</li>
     * <li>активировать дополнительные способы возврата</li>
     * <li>сгруппировать несколько транзакций для возврата одной транзакцией</li>
     * </ul>
     * <p>
     * Метода не должен содержать обращения к процессингу, взаимодействие с UI или другие потенциально долгие или блокирующие операции.
     * Касса вызывает метод как минимум один раз при каждом изменении данных, участвующих в расчете доступных для возврата транзакции.
     * Касса может вызывать метод неограниченное число раз, реализация метода должна быть идемпотентной.
     * <p>
     *
     * @param preparationRequest данные запроса на подготовку к возврату
     * @return результат подготовки возврата плагином. Может быть <code>null</code>, если результат нет
     */
    RefundPreparationResult prepareRefund(RefundPreparationRequest preparationRequest);
}
