package ru.crystals.pos.api.plugin.asset;

import java.util.Collections;
import java.util.List;

/**
 * Интерфейс для получения ресурсов плагина, например, картинок.
 * Ожидается, что будет реализован каким-либо плагином, например {@link ru.crystals.pos.api.plugin.PaymentPlugin}.
 */
public interface AssetProvider {

    /**
     * Метод для получения изображений плагина, которые могут быть использованы на кассе для разных нужд
     * (например, для отображения картинки плагина на стартовом экране кассы/на экране выбора оплат)
     *
     * @param criteria - критерии изображений
     * @return список изображений, подходящих критериям запроса
     */
    default List<ImageAsset> getImages(ImageCriteria criteria) {
        return Collections.emptyList();
    }

    /**
     * Метод для получения HTML-фрагментов, которые могут быть использованы для встраивания на кассе.
     * <p>
     * Позволяет плагинам кастомизировать отображение различной информации.
     *
     * @param criteria критерии HTML-фрагментов
     * @return список HTML-фрагментов, подходящих критериям запроса
     */
    default List<HtmlAsset> getHtmlAssets(HtmlAssetCriteria criteria) {
        return Collections.emptyList();
    }

}
