package ru.crystals.pos.api.plugin.function.dto;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/**
 * Позиция чека в {@link Receipt}
 */
public class Position {

    /**
     * Товар
     */
    private Product product;

    /**
     * Номер позиции
     */
    private int number;

    /**
     * Количество
     */
    private Long quantity;

    /**
     * Конечная стоимость позиции ((price * quantity) - discountAmount)
     */
    private BigDecimal amount;

    /**
     * Суммы скидки
     */
    private BigDecimal discountAmount;

    /**
     * Контрольная марка
     */
    private String mark;

    /**
     * Признак: "Разрешено редактировать позицию"
     * true - разрешено удалять, изменять кол-во и цену
     */
    private boolean editable;

    /**
     * Дополнительные данные позиции &lt;ключ, значение&gt;
     * В качестве ключа можно текстовое представление констант из {@link PositionDataKey} или произвольный текстовый ключ.
     * Если используется {@link PositionDataKey}, то значение касса может обработать и выполнить доп. действия
     * Если используется произвольный ключ, то значение просто сохраняется в плагиных свойствах позиции.
     */
    private Map<String, String> data;

    public Position(Product product) {
        this.product = product;
    }

    public Product getProduct() {
        return product;
    }

    public int getNumber() {
        return number;
    }

    public void setNumber(int number) {
        this.number = number;
    }

    public Long getQuantity() {
        return quantity;
    }

    public void setQuantity(Long quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public BigDecimal getDiscountAmount() {
        return discountAmount;
    }

    public void setDiscountAmount(BigDecimal discountAmount) {
        this.discountAmount = discountAmount;
    }

    public String getMark() {
        return mark;
    }

    public void setMark(String mark) {
        this.mark = mark;
    }

    public boolean isEditable() {
        return editable;
    }

    public void setEditable(boolean editable) {
        this.editable = editable;
    }

    public Map<String, String> getData() {
        if (data == null) {
            data = new HashMap<>();
        }
        return data;
    }
}
