package ru.crystals.pos.api.plugin.payment;

import ru.crystals.pos.spi.plugin.payment.RefundPreparationRequest;

import java.util.List;
import java.util.Objects;

/**
 * Результат подготовки к возврату по чеку
 *
 * @since 1.5.0
 */
public class RefundPreparationResult {

    /**
     * Список замен для транзакций, переданных в {@link RefundPreparationRequest#getPaymentsToRefund()}.
     * <p>
     * Каждая транзакция, для которой требуются изменения, должна быть один и только один раз перечислена в поле {@link PaymentToRefundReplacement#getUsedFor()}} одной
     * из замен.
     * <p>
     * Если одна и та же транзакция встречается больше одного раза в разных заменах, то такие замены считаются недействительными и не применяются.
     * <p>
     * Если список замен пустой, то при возврате по чеку будет использоваться список транзакций {@link RefundPreparationRequest#getPaymentsToRefund()} без изменений.
     */
    private final List<PaymentToRefundReplacement> paymentReplacements;

    public RefundPreparationResult(List<PaymentToRefundReplacement> replacements) {
        this.paymentReplacements = Objects.requireNonNull(replacements);
    }

    public List<PaymentToRefundReplacement> getPaymentReplacements() {
        return paymentReplacements;
    }

    @Override
    public String toString() {
        return "RefundPreparationResult{" +
               "paymentReplacements=" + paymentReplacements +
               '}';
    }
}
