package ru.crystals.pos.spi;

import ru.crystals.pos.spi.receipt.Merchandise;

/**
 * Шаблон кассы.<br>
 *
 * Под шаблоном кассы понимается касса с выделенным функционалом - касса продажи алкоголя, касса возвратов, касса в линейке, etc.
 * Шаблоны касс заводятся и настраиваются пользователем, посему могут иметь любое название и конфигурацию. Однако каждый такой шаблон
 * имеет свой уникальный идентификатор, который и возвращается этим методом.
 *
 * @since 0.0.96
 */
public interface POSTemplate {

    /**
     * Возвращает идентификатор шаблона кассы.
     *
     * @return идентификатор шаблона кассы
     */
    long getGuid();

    /**
     * Возвращает флаг разрешающий или запрещающий работу с юридическими лицами.
     *
     * @return true если работа с юридическими лицами разрешена, false в противном случае
     */
    boolean isProcessJuristicPerson();

    /**
     * Возвращает флаг разрешающий или запрещающий продажу юридическим лицам определенных типов товаров.
     *
     * @see Merchandise#isForbidSaleJuristicPerson()
     * @return true если продажа определенных типов товаров юридическим лицам разрешена, false в противном случае
     */
    boolean areAllProductTypesForJuristicPersonAllowed();
}
