package ru.crystals.pos.spi.plugin.payment;

import ru.crystals.pos.spi.receipt.Receipt;

import java.math.BigDecimal;

/**
 * Интерфейс запроса на выполнение оплаты.
 */
public interface PaymentRequest {

    /**
     * Текущий чек, который необходимо оплатить.
     * 
     * @return чек - {@link Receipt}
     */
    Receipt getReceipt();

    /**
     * Максимальная сумма которую можно использовать для оплаты.
     * Может быть получена кассой из внешнего чека или др. источников.
     * Если null, 0 или меньше 0, считаем что лимита нет.
     *
     * @return сумма с двумя знаками после запятой, т.е. scale=2
     */
    default BigDecimal getLimitSum() {
        return BigDecimal.ZERO;
    }

    /**
     * Интерфейс для оповещения кассы о результатах выполнения оплаты.
     * 
     * @return {@link PaymentCallback}
     */
    PaymentCallback getPaymentCallback();

}
