package ru.crystals.pos.spi.plugin.payment;

import ru.crystals.pos.api.plugin.payment.PaymentToRefundReplacement;
import ru.crystals.pos.api.plugin.payment.RefundPreparationResult;
import ru.crystals.pos.spi.receipt.Receipt;

import java.math.BigDecimal;
import java.util.List;

/**
 * Запрос на возврат одной или нескольких транзакций оплаты
 *
 * @since 1.5.0
 */
public interface TransactionalRefundRequest {
    /**
     * Текущий чек возврата
     *
     * @return чек возврата
     */
    Receipt getRefundReceipt();

    /**
     * Сумма, которая будет возвращена при успешном выполнении этого запроса
     * <p>
     * Совпадает с суммой {@link PaymentToRefund#getSumToRefund()} всех транзакций для возврата {@link #getPaymentsToRefund()}
     *
     * @return сумма к возврату
     */
    BigDecimal getSumToRefund();

    /**
     * Чек продажи, возврат которого сейчас выполняется
     *
     * @return чек продажи, не может быть null, поскольку {@link TransactionalRefundRequest} используется только при возврате по чеку
     */
    Receipt getOriginalReceipt();

    /**
     * Список транзакций, которые планируется вернуть в рамках этого запроса на возврат
     * <p>
     * При возврате потранзакционно содержит только одну транзакцию. Несколько транзакций могут быть переданы только при объединении транзакций плагином в
     * {@link RefundPreparationResult#getPaymentReplacements()} (см. {@link PaymentToRefundReplacement#getUsedFor()})
     * <p>
     * В текущей реализации содержит только транзакции, принадлежащие к тому же самому плагину
     *
     * @return список возвращаемых транзакций
     */
    List<PaymentToRefund> getPaymentsToRefund();

    /**
     * Для управления ходом выполнения и завершения процесса возврата из плагина
     */
    TransactionalRefundCallback getOperationCallback();

}
