package ru.crystals.pos.spi.receipt;

import java.math.BigDecimal;

/**
 * Интерфейс сущности акцизной бутылки алкогольного товара
 */
public interface ExciseBottle {

    /**
     * Артикул алкогольного товара
     *
     * @return артикул товара, не {@code null}
     */
    String getMarking();

    /**
     * Штрихкод бутылки
     *
     * @return строковое представление штрихкода бутылки, не {@code null}
     */
    String getBarcode();

    /**
     * Акцизная марка бутылки
     *
     * @return строковое представление кода акцизной марки, не {@code null}
     */
    String getExciseBarcode();

    /**
     * Цена бутылки
     *
     * @return цена с двумя знаками после запятой, не {@code null}
     */
    BigDecimal getPrice();

    /**
     * Объём бутылки
     *
     * @return объём бутылки или {@code null} если не задано
     */
    Double getVolume();

    /**
     * Крепость алкоголя в бутылке
     *
     * @return значение крепости или {@code null} если не задано
     */
    Double getAlcoholContent();

    /**
     * Артикул бутылки-компонента промонабора
     * @return значение артикулы бытылки или {@code null} если не задано
     */
    default String getBottleItem() {
        return null;
    }

}
