package ru.crystals.pos.spi.ui;

/**
 * Описание столбца в таблице, поддерживающей выбор строк.
 *
 * @see TableFormParameters
 */
public class TableSelectionFormColumn extends TableFormColumn {

    /**
     * Выравнивание в столбце.
     */
    public enum Alignment {
        LEFT,
        CENTER,
        RIGHT
    }

    /**
     * Выравнивание в столбце.
     */
    private final Alignment alignment;

    /**
     * Признак столбца для выбора строк (чекбокс). Допустимые значения в строке для данного столбца "true" и "false".
     */
    private final boolean selector;

    /**
     * Конструктор.
     *
     * @param title заголовок столбца
     * @param key   ключ, по которому будут получаться значения для этого столбца из Map
     * @param width ширина столбца (в процентах)
     */
    public TableSelectionFormColumn(String title, String key, int width) {
        this(title, key, width, Alignment.CENTER, false);
    }

    /**
     * Конструктор.
     *
     * @param title     заголовок столбца
     * @param key       ключ, по которому будут получаться значения для этого столбца из Map
     * @param width     ширина столбца (в процентах)
     * @param alignment выравнивание в столбце
     */
    public TableSelectionFormColumn(String title, String key, int width, Alignment alignment) {
        this(title, key, width, alignment, false);
    }

    /**
     * Конструктор.
     *
     * @param title     заголовок столбца
     * @param key       ключ, по которому будут получаться значения для этого столбца из Map
     * @param width     ширина столбца (в процентах)
     * @param alignment выравнивание в столбце
     * @param selector  признак столбца для выбора строк (чекбокс)
     */
    public TableSelectionFormColumn(String title, String key, int width, Alignment alignment, boolean selector) {
        super(title, key, width);
        this.alignment = alignment;
        this.selector = selector;
    }

    /**
     * Возвращает выравнивание в столбце.
     *
     * @return выравнивание в столбце
     */
    public Alignment getAlignment() {
        return alignment;
    }

    /**
     * Возвращает признак столбца для выбора строк (чекбокс).
     * Допустимые значения в строке для данного столбца "true" и "false".
     *
     * @return признак столбца для выбора строк (чекбокс)
     */
    public boolean isSelector() {
        return selector;
    }
}
