package ru.crystals.pos.spi.ui.webview;

import ru.crystals.pos.api.ui.listener.ScanFormListener;
import ru.crystals.pos.api.ui.listener.WebViewCloseListener;
import ru.crystals.pos.api.ui.listener.WebViewMessageListener;

import java.util.EnumSet;
import java.util.Optional;

public class ShowWebViewParameters {
    public static Builder builder() {
        return new Builder();
    }

    /**
     * URL для показа в WebView
     */
    private final String url;
    /**
     * Тип отображения WebView
     */
    private final WebViewShowType showType;
    /**
     * Цвет фона WebView на время его загрузки
     */
    private final String color;
    /**
     * Правила обработки событий во время открытого WebView
     */
    private final EnumSet<EventsProcessingRule> eventsProcessingRules;
    /**
     * Обработчик сообщений с WebView
     */
    private final WebViewMessageListener messageListener;
    /**
     * Обработчик события "Закрытие WebView"
     */
    private final WebViewCloseListener closeListener;
    /**
     * Обработчик событий сканера
     */
    private final ScanFormListener scanFormListener;

    public ShowWebViewParameters(String url, WebViewShowType showType, String color, EnumSet<EventsProcessingRule> eventsProcessingRules,
                                 WebViewMessageListener messageListener, WebViewCloseListener closeListener, ScanFormListener scanFormListener) {
        this.url = url;
        this.showType = showType;
        this.color = color;
        this.eventsProcessingRules = eventsProcessingRules;
        this.messageListener = messageListener;
        this.closeListener = closeListener;
        this.scanFormListener = scanFormListener;
    }

    public String getUrl() {
        return url;
    }

    public WebViewShowType getShowType() {
        return showType;
    }

    public String getColor() {
        return color;
    }

    public EnumSet<EventsProcessingRule> getEventsProcessingRules() {
        return eventsProcessingRules;
    }

    public Optional<WebViewMessageListener> getMessageListener() {
        return Optional.of(messageListener);
    }

    public Optional<WebViewCloseListener> getCloseListener() {
        return Optional.of(closeListener);
    }

    public Optional<ScanFormListener> getScanFormListener() {
        return Optional.of(scanFormListener);
    }

    public static class Builder {
        String url;
        WebViewShowType showType = WebViewShowType.FULL_SCREEN;
        String color;
        EnumSet<EventsProcessingRule> eventsProcessingRules = EnumSet.noneOf(EventsProcessingRule.class);
        WebViewMessageListener messageListener = (message, callback) -> {
        };
        WebViewCloseListener closeListener = () -> {
        };
        ScanFormListener scanFormListener = getEmptyScanFormListener();

        public Builder url(String url) {
            this.url = url;
            return this;
        }

        public Builder showType(WebViewShowType showType) {
            this.showType = showType;
            return this;
        }

        public Builder color(String color) {
            this.color = color;
            return this;
        }

        public Builder eventProcessingRules(EnumSet<EventsProcessingRule> eventsProcessingRules) {
            this.eventsProcessingRules = eventsProcessingRules;
            return this;
        }

        public Builder messageListener(WebViewMessageListener messageListener) {
            this.messageListener = messageListener;
            return this;
        }

        public Builder closeListener(WebViewCloseListener closeListener) {
            this.closeListener = closeListener;
            return this;
        }

        public Builder scanFormListener(ScanFormListener scanFormListener) {
            this.scanFormListener = scanFormListener;
            return this;
        }

        public ShowWebViewParameters build() {
            return new ShowWebViewParameters(url, showType, color, eventsProcessingRules, messageListener, closeListener, scanFormListener);
        }

        private ScanFormListener getEmptyScanFormListener() {
            return new ScanFormListener() {
                @Override
                public void eventBarcodeScanned(String barcode) {

                }

                @Override
                public void eventCanceled() {

                }
            };
        }
    }
}
